==> ejc-businessplan-impl-3.0.0-20220225.080726-13-sources.jar: com/ejianc/business/busniessplan/vo/BusinessplanningeffectVO.java <==
package com.ejianc.business.busniessplan.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.busniessplan.vo.BusinessplanningeffectdetailVO;

/**
 * 项目商务策划效果
 * 
 * @author generator
 * 
 */
public class BusinessplanningeffectVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编码
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.Long agentId; // 经办人id
    private java.lang.String agentName; // 经办人名称
    private java.math.BigDecimal costEstimateTotal; // 成本估算
    private java.math.BigDecimal reportAmountTotal; // 上报预算汇总
    private java.math.BigDecimal targetAmountTotal; // 策划目标金额汇总
    private java.math.BigDecimal completeAmountTotal; // 已完成目标金额汇总
    private java.math.BigDecimal estimateProfitsTotal; // 预计利润汇总
    private java.lang.String remarks; // 备注
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    
    private List<BusinessplanningeffectdetailVO> businessplanningeffectdetailEntities = new ArrayList<>(); // 项目商务策划效果子表

    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人id
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    @ReferDeserialTransfer
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人名称
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 成本估算
     */
    public java.math.BigDecimal getCostEstimateTotal() {
        return costEstimateTotal;
    }

    /**
     * 成本估算
     */
    public void setCostEstimateTotal(java.math.BigDecimal costEstimateTotal) {
        this.costEstimateTotal = costEstimateTotal;
    }
    /**
     * 上报预算汇总
     */
    public java.math.BigDecimal getReportAmountTotal() {
        return reportAmountTotal;
    }

    /**
     * 上报预算汇总
     */
    public void setReportAmountTotal(java.math.BigDecimal reportAmountTotal) {
        this.reportAmountTotal = reportAmountTotal;
    }
    /**
     * 策划目标金额汇总
     */
    public java.math.BigDecimal getTargetAmountTotal() {
        return targetAmountTotal;
    }

    /**
     * 策划目标金额汇总
     */
    public void setTargetAmountTotal(java.math.BigDecimal targetAmountTotal) {
        this.targetAmountTotal = targetAmountTotal;
    }
    /**
     * 已完成目标金额汇总
     */
    public java.math.BigDecimal getCompleteAmountTotal() {
        return completeAmountTotal;
    }

    /**
     * 已完成目标金额汇总
     */
    public void setCompleteAmountTotal(java.math.BigDecimal completeAmountTotal) {
        this.completeAmountTotal = completeAmountTotal;
    }
    /**
     * 预计利润汇总
     */
    public java.math.BigDecimal getEstimateProfitsTotal() {
        return estimateProfitsTotal;
    }

    /**
     * 预计利润汇总
     */
    public void setEstimateProfitsTotal(java.math.BigDecimal estimateProfitsTotal) {
        this.estimateProfitsTotal = estimateProfitsTotal;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    
     /**
      * 项目商务策划效果子表
      */
     public List<BusinessplanningeffectdetailVO> getBusinessplanningeffectdetailEntities() {
        return businessplanningeffectdetailEntities;
     }

     /**
      * 项目商务策划效果子表
      */
     public void setBusinessplanningeffectdetailEntities(List<BusinessplanningeffectdetailVO> businessplanningeffectdetailEntities) {
        this.businessplanningeffectdetailEntities = businessplanningeffectdetailEntities;
     }
}

==> ejc-businessplan-impl-3.0.0-20220329.134247-55-sources.jar: com/ejianc/business/busniessplan/vo/BusinessplanningeffectVO.java <==
package com.ejianc.business.busniessplan.vo;

import java.util.List;
import java.util.ArrayList;

import com.ejianc.business.record.vo.RecordbusinessplanningeffectVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 项目商务策划效果
 * 
 * @author generator
 * 
 */
public class BusinessplanningeffectVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编码
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.Long agentId; // 经办人id
    private java.lang.String agentName; // 经办人名称
    private java.math.BigDecimal costEstimateTotal; // 成本估算
    private java.math.BigDecimal reportAmountTotal; // 上报预算汇总
    private java.math.BigDecimal targetAmountTotal; // 策划目标金额汇总
    private java.math.BigDecimal completeAmountTotal; // 已完成目标金额汇总
    private java.math.BigDecimal estimateProfitsTotal; // 预计利润汇总
    private java.lang.String remarks; // 备注
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更

    private java.lang.String createTimeShow; // 创建时间文本显示
    private java.lang.String billStateStr; // 单据状态文本显示

    private java.lang.String sort; // 序号

    private List<BusinessplanningeffectdetailVO> businessplanningeffectdetailEntities = new ArrayList<>(); // 项目商务策划效果子表
    private List<RecordbusinessplanningeffectVO> recordbusinessplanningeffectList = new ArrayList<>(); // 历史信息

    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    public String getCreateTimeShow() {
        return createTimeShow;
    }

    public void setCreateTimeShow(String createTimeShow) {
        this.createTimeShow = createTimeShow;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人id
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    @ReferDeserialTransfer
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人名称
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 成本估算
     */
    public java.math.BigDecimal getCostEstimateTotal() {
        return costEstimateTotal;
    }

    /**
     * 成本估算
     */
    public void setCostEstimateTotal(java.math.BigDecimal costEstimateTotal) {
        this.costEstimateTotal = costEstimateTotal;
    }
    /**
     * 上报预算汇总
     */
    public java.math.BigDecimal getReportAmountTotal() {
        return reportAmountTotal;
    }

    /**
     * 上报预算汇总
     */
    public void setReportAmountTotal(java.math.BigDecimal reportAmountTotal) {
        this.reportAmountTotal = reportAmountTotal;
    }
    /**
     * 策划目标金额汇总
     */
    public java.math.BigDecimal getTargetAmountTotal() {
        return targetAmountTotal;
    }

    /**
     * 策划目标金额汇总
     */
    public void setTargetAmountTotal(java.math.BigDecimal targetAmountTotal) {
        this.targetAmountTotal = targetAmountTotal;
    }
    /**
     * 已完成目标金额汇总
     */
    public java.math.BigDecimal getCompleteAmountTotal() {
        return completeAmountTotal;
    }

    /**
     * 已完成目标金额汇总
     */
    public void setCompleteAmountTotal(java.math.BigDecimal completeAmountTotal) {
        this.completeAmountTotal = completeAmountTotal;
    }
    /**
     * 预计利润汇总
     */
    public java.math.BigDecimal getEstimateProfitsTotal() {
        return estimateProfitsTotal;
    }

    /**
     * 预计利润汇总
     */
    public void setEstimateProfitsTotal(java.math.BigDecimal estimateProfitsTotal) {
        this.estimateProfitsTotal = estimateProfitsTotal;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    
     /**
      * 项目商务策划效果子表
      */
     public List<BusinessplanningeffectdetailVO> getBusinessplanningeffectdetailEntities() {
        return businessplanningeffectdetailEntities;
     }

     /**
      * 项目商务策划效果子表
      */
     public void setBusinessplanningeffectdetailEntities(List<BusinessplanningeffectdetailVO> businessplanningeffectdetailEntities) {
        this.businessplanningeffectdetailEntities = businessplanningeffectdetailEntities;
     }

    public List<RecordbusinessplanningeffectVO> getRecordbusinessplanningeffectList() {
        return recordbusinessplanningeffectList;
    }

    public void setRecordbusinessplanningeffectList(List<RecordbusinessplanningeffectVO> recordbusinessplanningeffectList) {
        this.recordbusinessplanningeffectList = recordbusinessplanningeffectList;
    }
}
